Contributors
============

The Colour Developers
---------------------

-   **Thomas Mansencal**, *Principal Pipeline Programmer @ Epic Games*

    Maintainer, project coordination, overall development.

-   **Michael Mauderer**, *Researcher & Senior Developer @ Enso*

    Maintainer, colour appearance models, overall development.

-   **Nick Shaw**, *Workflow Consultant @ Antler Post*

    Maintainer, Y'CbCr colour encoding, RED colourspaces derivation, LUT IO, continuous technical support.

-   **Zach Lewis**, *Technical Director @ Method Studios*

    Maintainer, CLF, technical support.

-   **Michael Parsons**, *Colour Scientist @ DNEG*

    Maintainer, technical support.

-   **Kevin Wheatley**, *Head of Imaging @ Framestore*

    Technical support.

-   **Sean Cooper**, *Colour Scientist @ ARRI*

    Technical support.

-   **Jean D. Vandenberg**, *Director of Engineering @ Picture Shop*

    Technical support.

-   **Tucker Downs**, *R&D Manager & Color Scientist @ ROE Visual*

    Maintainer, overall development.

Google Summer of Code
---------------------

2020
~~~~

-   **Nishant Joywardhan**, *Student @ Cluster Innovation Centre, University of Delhi*

    LUT IO Improvements.

-   **Pawel Redman**, *Student @ Wrocław University of Science and Technology*

    New Spectral Upsampling Methods.

-   **Omar Wagih**, *Student @ Faculty of Engineering, Cairo University*

    The Need for Speed.

2021
~~~~

-   **Cédric Dollet**, *Student @ CY Tech, France*

    New Colour Appearance Models.

-   **Geetansh Saxena**, *Student @ Cluster Innovation Centre, University of Delhi*

    New Colour Models.

Development & Technical Support
-------------------------------

-   **Luke Canavan**

    Colour Quality Scale, luminous flux.

-   **Katherine Crowson**

    CIECAM02 improvements, technical support.

-   **Ofek Lev**

    Documentation improvements.

-   **Katrin Leinweber**

    Documentation improvements.

-   **Shriramana Sharma**

    Documentation improvements.

-   **Troy James Sobotka**, *Motion Picture Technician*

    F-Gamut and Fuji F-Log support.

-   **Dominik Moritz**, *PhD in Computer Science @ University of Washington*

    Documentation improvements.

-   **Matt Pppp**

    *Hacktoberfest 2019* technical support.

-   **Chinmay Rane**

    *Hacktoberfest 2019* technical support.

-   **Pavithra Eswaramoorthy**

    *Hacktoberfest 2019* technical support.

-   **John Mertic**

    License discovery improvements.

-   **Ben Pearlstine**

    *Hacktoberfest 2019* technical support.

-   **Manuel Leonhardt**, *Software Engineer and Image Scientist @ ARRI*

    Documentation improvements.

-   **Olli Niemitalo**

    Krystek (1985) implementation fixes.

-   **Marek Szymanski**

    Numpy 1.18 compatibility.

-   **Maximilian Schambach**

    Python 3.8 compatibility.

-   **Sianyi Huang**, *Display Tuning Engineer*

    Examples fixes.

-   **Mike Wei**, *Display Tuning Engineer*

    Technical support.

-   **Joseph Goldstone**, *Image Science Engineer @ ARRI*

    Technical support and documentation improvements.

-   **Stephen Hill**, *Principal Rendering Engineer @ Lucasfilm*

    Documentation improvements.

-   **Jedediah Smith**, *VFX Supervisor @ Method Studios*

    RED Log3G10 improvements.

-   **Frederic Savoir**, *Technology Director @ Amazing Digital Studios*

    DaVinci Intermediate OETF implementation.

-   **Saransh Chopra**, *Student @ Cluster Innovation Centre, University of Delhi*

    HCL colourspace implementation.

-   **Ilia Sibiryakov**, *Student @ University of Portsmouth*

    Helmholtz—Kohlrausch effect implementation.

-   **Tim Gates**

    Documentation improvements.

-   **Gajendra Pal**

    Documentation improvements.

-   **Nicolas Tessore**

    Technical support.

-   **Aurélien Pierre**, *Core Developer @ darktable-org*

    Documentation improvements.

-   **François-Xavier Thomas**, *Senior Image Science Engineer @ DXOMARK*

    Support for Recommendation ITU-T H.273 / INTERNATIONAL STANDARD ISO/IEC 23091-2.

-   **Sabarish Srinivasan**, *SWE Intern @ SmallHD*

    Support for Recommendation ITU-R BT.2124-0.

-   **Kiliansas (@Rusching)**

    TE226 v2 colour checker reference values.

-   **Xiaohan Chen (@chnmasta05)**

    Cheung et al. (2004) polynomial correction improvements.

-   **Benjamin Herb**, *Author @ benjaminherb.de*

    Spectral Similarity Index computation improvements.

-   **Thomas A Caswell**, *Computational Scientist @ Brookhaven National Laboratory*

    Typing annotations improvements.

-   **Liam Collod**, *VFX Software Developer @ Mikros Animation*

    Documentation improvements.

Acknowledgements
----------------
-   **Steve Agland**, *Supervising Lighting Technical Director @ Animal Logic*

    Technical support.

-   **Tim Borer**, *Lead Engineer @ BBC Research & Development*

    *ITU-R BT.2100* technical support.

-   **Paul Centore**, *Mathematician & Colour Scientist*

    Matlab *Munsell Renotation System* implementation.

-   **Scott Dyer**, *Image Engineering @ Academy of Motion Picture Arts and Sciences*

    *ACES RGB IDT* technical support.

-   **Mark D. Fairchild**, *Director @ Munsell Color Science Lab, Director @ Program of Color Science*

    Technical support.

-   **Alex Forsythe**, *Image Engineering Manager @ Academy of Motion Picture Arts and Sciences*

    *ACES RGB IDT* technical support.

-   **Yoshi Ohno**, *Mathematician & Colour Scientist*

    *Ohno (2013)* correlated colour temperature calculation technical support.

-   **Charles Poynton**, *Mathematician & Colour Scientist*

    Technical support.

Special Mentions
----------------

-   **Aurélia Sellier**, *Production Manager @ Wētā FX*

Issues & Discussions
--------------------

-   Albert Szostkiewicz
-   Christophe Go
-   Giuseppe Di Guglielmo
-   Iman Sajedian
-   Marie Meyer
-   Max Marrone
-   Michal Krompiec
-   Nick Porcino
-   Nick Spiker
-   Ryan Bass
-   Vishal Vashistha
-   Vlad Enache
-   @Alt-Shivam
-   @Ampersandme
-   @AndersAtEndian
-   @Apoorva-13
-   @Artoria2e5
-   @BQ-Octantis
-   @CHRIBUR0309
-   @Chandler
-   @ChunHsinWang
-   @Edwardlin-zlt
-   @EricFlyMeToTheMoon
-   @Floschoe
-   @GuillemRamisa
-   @JarrettR
-   @JayPalm
-   @Jerry2001
-   @JopdeBoo
-   @JoshuaEbenezer
-   @KOLANICH
-   @KrisKennaway
-   @Kunkka1988
-   @LandonSwartz
-   @LaughingMaann
-   @LeCyberDucky
-   @Legendin
-   @MMehdiMousavi
-   @MadhuSN
-   @MarcusCalhoun-Lopez
-   @MrColourBlind
-   @Myndex
-   @Naughty-Monkey
-   @NekoAlosama
-   @NoRoKr
-   @Patil2099
-   @Paul-Sims
-   @Queuecumber
-   @Rob-Welch
-   @Ron024
-   @RutNij
-   @TFiFiE
-   @TomFryers
-   @ValZapod
-   @Voultapher
-   @Wagyx
-   @Wangld5
-   @Willingo
-   @aarondemolder
-   @abnormally-distributed
-   @ademmler
-   @ahemberger
-   @alban-sol
-   @alianoroozi
-   @altert
-   @alyfreym
-   @am-ac
-   @andurilhuang
-   @anshulxyz
-   @aurelienbl
-   @awehring
-   @baileyji
-   @barisduzenli
-   @beckstev
-   @bersbersbers
-   @bhive01
-   @blue-j
-   @brandondube
-   @briend
-   @bsdis
-   @camilo1704
-   @cclauss
-   @chesschi
-   @codycuellar
-   @cuixiaofei
-   @da5nsy
-   @daviesj
-   @dfoxfranke
-   @digital-prepress
-   @diuming
-   @dofuuz
-   @domisjustanumber
-   @dtbulmerJRs
-   @eitanlees
-   @ema2159
-   @ems1111
-   @eyeforcolor
-   @fangjy88
-   @foutoucour
-   @fxthomas
-   @goofy2k
-   @gutenzwerg
-   @habemus-papadum
-   @hajimen
-   @hakanai
-   @harshjain30
-   @heinemannj
-   @henczati
-   @hminle
-   @iCagarro
-   @iinnovations
-   @jaguarondi
-   @jamesmyatt
-   @jamesmyatt
-   @juneleung
-   @kaihagseth
-   @kamikaze
-   @kljumat
-   @kunal9922
-   @lavrovd
-   @leklbk
-   @lensz
-   @lishichengyan
-   @lulunac27a
-   @luoww1992
-   @materialjan
-   @matt-roberts
-   @matthiasbirkich
-   @meshing
-   @mesvam
-   @mforbes
-   @mokincha
-   @monkeywithacupcake
-   @naavis
-   @nadersadoughi
-   @nico
-   @nitishn23
-   @nschloe
-   @opanyaki
-   @parthxtripathi
-   @peteroupc
-   @pfk-beta
-   @physici
-   @pjaesung2
-   @priikone
-   @qiuboujun
-   @ramparvathaneni
-   @richardstardust
-   @robbuckley
-   @romanovar
-   @rsnitsch
-   @sdbbs
-   @senyai
-   @shanest
-   @sherlockedlee
-   @shirubana
-   @shpurdikhub
-   @sliedes
-   @soldivelot
-   @spicymatt
-   @ssh4net
-   @stakemura
-   @starkcolour
-   @starkfan007
-   @stereomatchingkiss
-   @tashdor
-   @teja275
-   @thunders82
-   @tingeman
-   @tospe
-   @totyped
-   @ujjayants
-   @vibhoothi
-   @vidakDK
-   @volkerjaenisch
-   @volrak
-   @vsohler
-   @vvclin-git
-   @whornsby
-   @willSmallHD
-   @wuuawu
-   @xeggbee
-   @xjossy
-   @yuhao
-   @yulincoder
-   @zanyc-smm

About
-----

| **Colour** by Colour Developers
| Copyright 2013 Colour Developers – `colour-developers@colour-science.org <colour-developers@colour-science.org>`__
| This software is released under terms of BSD-3-Clause: https://opensource.org/licenses/BSD-3-Clause
| `https://github.com/colour-science/colour <https://github.com/colour-science/colour>`__
